==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Mìnga benda sounoura',
	'aucun_document' => 'Mìnga doucumen',
	'aucun_file' => 'Mìnga doucumen',
	'aucun_image' => 'Mìnga image',
	'aucun_video' => 'Mìnga sequènsa',
	'aucune_utilisation' => 'Aquéu doucumen es pas utilisat',
	'aucune_vignette' => 'Mìnga vigneta',

	// B
	'bouton_ajouter_document' => 'Ajustà un doucumen',
	'bouton_ajouter_image' => 'Ajustà una image',
	'bouton_ajouter_image_document' => 'Ajustà una image o un doucumen',
	'bouton_attacher_document' => 'Estacà',
	'bouton_copier_local' => 'Coupià en lou sit',
	'bouton_download_depuis' => 'despì :',
	'bouton_download_local' => 'lou miéu ourdinatour',
	'bouton_download_par_ftp' => 'lou servidou',
	'bouton_download_par_mediatheque' => 'la mediatèca',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Destacà',
	'bouton_enlever_supprimer_document' => 'Suprimà',
	'bouton_enlever_supprimer_document_confirmation' => 'Sias segur de voulé suprimà lou doucumen ?',
	'bouton_modifier_document' => 'Moudificà',
	'bouton_parcourir' => 'Escourre…',
	'bouton_refresh_document' => 'Atualisà lou doucumen',
	'bouton_remplacer_document' => 'Remplaçà aqueu doucumen',
	'bouton_remplacer_image' => 'Remplaçà aqueula image',
	'bouton_remplacer_image_document' => 'Remplaçà per una image o un doucumen',
	'bouton_supprimer' => 'Suprimà',
	'bouton_supprimer_tous_orphelins' => 'Suprimà toui lu ourfanèu',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sias segur de voulé suprimà @nb@ ourfanèu ?',
	'bouton_upload' => 'Televersà',

	// D
	'des_audios' => '@nb@ benda sounouri',
	'des_documents' => '@nb@ doucumen',
	'des_files' => '@nb@ doucumen',
	'des_images' => '@nb@ image',
	'des_utilisations' => '@nb@ utilisacioun',
	'des_videos' => '@nb@ sequènsa',
	'descriptif' => 'Descricioun',
	'document_attache_succes' => 'Lou doucumen es ben estat ajustat',
	'document_copie_locale_succes' => 'Lou fichié es ben estat coupiat en lou sit',
	'document_installe_succes' => 'Lou fichié es ben estat cargat',
	'document_vu' => 'Inserit en lou tèstou',
	'documents' => 'Mediatèca',
	'documents_brises' => 'Courroumput',
	'documents_distants' => 'Distant',
	'documents_locaux' => 'Loucal',
	'documents_non_publies' => 'Noun publicat',
	'documents_orphelins' => 'Inutilisat',
	'documents_publies' => 'Publicat',
	'documents_tous' => 'Toui',
	'double_clic_inserer_doc' => 'Besclicas per inserì aqueu escourcha en lou tèstou',

	// E
	'entree_dimensions' => 'Dimensioun :',
	'entree_titre_document' => 'Titre dóu doucumen :',
	'entree_titre_image' => 'Titre de l’image :',
	'erreur_aucun_document' => 'Aqueu doucumen noun esista en la mediatèca',
	'erreur_aucun_fichier' => 'Mìnga fichié es estat troubat',
	'erreur_chemin_distant' => 'Lou fichié distant @nom@ a pas pouscut estre troubat',
	'erreur_chemin_ftp' => 'Lou fichié endicat es pas estat troubat soubre lou servidou',
	'erreur_copie_fichier' => 'Empoussible de coupià lou fichié @nom@',
	'erreur_dossier_tmp_manquant' => 'Manca un doussié tempourari da telecargà lu fichié',
	'erreur_ecriture_fichier' => 'Errour en tant que lou fichié s’escrieuguèsse sus lou disc',
	'erreur_format_fichier_image' => 'Lou fourmat de @nom@ noun counven a una image',
	'erreur_indiquez_un_fichier' => 'Endicas un fichié !',
	'erreur_insertion_document_base' => 'Empoussible de registrà lou doucumen @fichier@ en basa de dounada',
	'erreur_suppression_vignette' => 'Errour en tant que si suprimèsse la vigneta',
	'erreur_upload_type_interdit' => 'Lou telecargamen dei fichié de tìpou de @nom@ noun es autourisat',
	'erreur_upload_vignette' => 'Errour en tant que la vigneta @nom@ si cargue',
	'erreurs' => '@nb@ errour',
	'erreurs_voir' => 'Veire li @nb@ errour',

	// F
	'fichier_distant' => 'Fichié distant',
	'fichier_manquant' => 'Fichié mancant',
	'fichier_modifie' => 'Lou fichié es etat moudificat. Clicas soubre registrà.',
	'format_date_incorrect' => 'La data o l’oura es mau couret',

	// I
	'icone_creer_document' => 'Ajustà un doucumen',
	'id' => 'ID',
	'image_tourner_180' => 'Routacioun 180°',
	'image_tourner_droite' => 'Routacioun 90° a drecha',
	'image_tourner_gauche' => 'Routacioun 90° a seneca',
	'info_doc_max_poids' => 'Lu doucumen devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_document' => 'Doucumen',
	'info_document_indisponible' => 'Aquéu doucumen es pas dispounible',
	'info_documents' => 'Doucumen',
	'info_gauche_numero_document' => 'DOUCUMEN NUMERÒ',
	'info_hauteur' => 'Autessa',
	'info_heure' => 'Oura',
	'info_illustrations' => 'Ilustracioun',
	'info_image_max_poids' => 'Li image devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_image_max_taille' => 'Li image devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_inclusion_directe' => 'Enclusioun direta :',
	'info_inclusion_vignette' => 'Enclusioun de la vigneta :',
	'info_installer_tous_documents' => 'Instalà toui lu doucumen',
	'info_largeur' => 'Larguessa',
	'info_logo_max_taille' => 'Lu logou devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_mode' => 'Mòdou',
	'info_modifier_document' => 'Moudificà lou doucumen',
	'info_portfolio' => 'Pouòrtafoliò',
	'info_referencer_doc_distant' => 'Referençà un doucumen sus internet :',
	'info_sans_vignette' => 'Sensa vigneta',
	'info_statut_document' => 'Aquéu doucumen es :',
	'info_taille' => 'Pès',
	'info_telecharger' => 'Telecargà dau vouòstre ourdinatour :',
	'infos' => 'Infourmacioun tècniqui',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetre de moudificà la data de cada doucumen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei doucumen es aquela dóu siéu ajountamen sus lou sit',

	// L
	'label_activer_document_objets' => 'Ativà lou televersamen ai contengut :',
	'label_apercu' => 'Aperçut',
	'label_caracteristiques' => 'Caraterìstica',
	'label_credits' => 'Crèdi',
	'label_fichier' => 'Fichié',
	'label_fichier_vignette' => 'Vigneta',
	'label_paginer_par' => 'Paginà per :',
	'label_parents' => 'Aqueu doucumen es estacat da',
	'label_refdoc_joindre' => 'Doucumen numerò',
	'lien_tout_enlever' => 'Levà tout',
	'logo' => 'Logou',

	// M
	'media_audio' => 'Banda sounouri',
	'media_file' => 'Autre',
	'media_image' => 'Image',
	'media_video' => 'Sequènsa',
	'miniature_automatique_active' => 'SPIP genererà automaticamen una miniatura de l’image',

	// N
	'nb_documents_attache_succes' => '@nb@ doucumen soun ben estat ajustat',
	'nb_documents_installe_succes' => '@nb@ fichié cargat embé suchès',

	// O
	'objet_document' => 'Doucumen',
	'objet_documents' => 'Doucumen',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Autessa',
	'par_id' => 'ID',
	'par_largeur' => 'Larguessa',
	'par_taille' => 'Pès',
	'par_titre' => 'Titre',

	// T
	'texte_documents_joints' => 'Poudès ativà l’interfaça d’ajountamen de doucumen (fichié buròticou, image, multimedia, eca.) ai article, rùbrica e autre. Aquelu fichié pouòdon pi estre referençat en lou tèstou, o afichat separatamen.',
	'texte_documents_joints_2' => 'Aqueu reglage noun empedisse lou televersamen d’image en lu article ni l’ensercioun de doucumen diretamen en lu tèstou dei countengut.',
	'titre_documents_joints' => 'Doucumen jounch',
	'titre_page_documents_edit' => 'Moudificà lou doucumen : @titre@',
	'tous_les_medias' => 'Toui lu media',
	'tout_dossier_upload' => 'Tout lou doussié @upload@',
	'tout_voir' => 'Tout veire',

	// U
	'un_audio' => '1 banda sounoura',
	'un_document' => '1 doucumen',
	'un_file' => '1 doucumen',
	'un_image' => '1 image',
	'un_video' => '1 sequènsa',
	'une_utilisation' => '1 utilisacioun',
	'upload_fichier_zip' => 'Fichié ZIP',
	'upload_fichier_zip_texte' => 'Lou fichié que proupausas d’instalà es un fichié Zip.',
	'upload_fichier_zip_texte2' => 'Aquéu fichié pòu estre :',
	'upload_info_mode_document' => 'Depousà en lou pouòrtafoliò',
	'upload_info_mode_image' => 'Restirà dóu pouòrtafoliò',
	'upload_limit' => 'Aqueu fichié es tròu gros per lou servidou ; la talha massimala autourisada en <i>upload</i> es de @max@.',
	'upload_zip_conserver' => 'Counservà l’arquivi après estracioun',
	'upload_zip_decompacter' => 'descoumprimat e cada elemen que counten instalat sus lou sit. Lu fichié que seran pi instalat sus lou sit soun :',
	'upload_zip_mode_document' => 'Depousà touti li image en lou pouòrtafoliò',
	'upload_zip_telquel' => 'instalat tau quau, couma arquivi  coumprimat Zip ;',
	'upload_zip_titrer' => 'Titrà segoun lou noum dei fichié',

	// V
	'verifier_documents_brises' => 'Verificà lu fichié mancant',
	'verifier_documents_inutilises' => 'Verificà lu estac dei doucumen',
	'vignette_supprimee' => 'La vigneta es estada suprimada'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Mìnga benda sounoura',
	'aucun_document' => 'Mìnga doucumen',
	'aucun_file' => 'Mìnga doucumen',
	'aucun_image' => 'Mìnga image',
	'aucun_video' => 'Mìnga sequènsa',
	'aucune_utilisation' => 'Aquéu doucumen es pas utilisat',
	'aucune_vignette' => 'Mìnga vigneta',

	// B
	'bouton_ajouter_document' => 'Ajustà un doucumen',
	'bouton_ajouter_image' => 'Ajustà una image',
	'bouton_ajouter_image_document' => 'Ajustà una image o un doucumen',
	'bouton_attacher_document' => 'Estacà',
	'bouton_copier_local' => 'Coupià en lou sit',
	'bouton_download_depuis' => 'despì :',
	'bouton_download_local' => 'lou miéu ourdinatour',
	'bouton_download_par_ftp' => 'lou servidou',
	'bouton_download_par_mediatheque' => 'la mediatèca',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Destacà',
	'bouton_enlever_supprimer_document' => 'Suprimà',
	'bouton_enlever_supprimer_document_confirmation' => 'Sias segur de voulé suprimà lou doucumen ?',
	'bouton_modifier_document' => 'Moudificà',
	'bouton_parcourir' => 'Escourre…',
	'bouton_refresh_document' => 'Atualisà lou doucumen',
	'bouton_remplacer_document' => 'Remplaçà aqueu doucumen',
	'bouton_remplacer_image' => 'Remplaçà aqueula image',
	'bouton_remplacer_image_document' => 'Remplaçà per una image o un doucumen',
	'bouton_supprimer' => 'Suprimà',
	'bouton_supprimer_tous_orphelins' => 'Suprimà toui lu ourfanèu', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'Sias segur de voulé suprimà @nb@ ourfanèu ?', # MODIF
	'bouton_upload' => 'Televersà',

	// D
	'des_audios' => '@nb@ benda sounouri',
	'des_documents' => '@nb@ doucumen',
	'des_files' => '@nb@ doucumen',
	'des_images' => '@nb@ image',
	'des_utilisations' => '@nb@ utilisacioun',
	'des_videos' => '@nb@ sequènsa',
	'descriptif' => 'Descricioun',
	'document_attache_succes' => 'Lou doucumen es ben estat ajustat',
	'document_copie_locale_succes' => 'Lou fichié es ben estat coupiat en lou sit',
	'document_installe_succes' => 'Lou fichié es ben estat cargat',
	'document_vu' => 'Inserit en lou tèstou',
	'documents' => 'Mediatèca',
	'documents_brises' => 'Courroumput',
	'documents_distants' => 'Distant',
	'documents_locaux' => 'Loucal',
	'documents_non_publies' => 'Noun publicat',
	'documents_orphelins' => 'Inutilisat',
	'documents_publies' => 'Publicat',
	'documents_tous' => 'Toui',
	'double_clic_inserer_doc' => 'Besclicas per inserì aqueu escourcha en lou tèstou',

	// E
	'entree_dimensions' => 'Dimensioun :',
	'entree_titre_document' => 'Titre dóu doucumen :',
	'entree_titre_image' => 'Titre de l’image :',
	'erreur_aucun_document' => 'Aqueu doucumen noun esista en la mediatèca',
	'erreur_aucun_fichier' => 'Mìnga fichié es estat troubat',
	'erreur_chemin_distant' => 'Lou fichié distant @nom@ a pas pouscut estre troubat',
	'erreur_chemin_ftp' => 'Lou fichié endicat es pas estat troubat soubre lou servidou',
	'erreur_copie_fichier' => 'Empoussible de coupià lou fichié @nom@',
	'erreur_dossier_tmp_manquant' => 'Manca un doussié tempourari da telecargà lu fichié',
	'erreur_ecriture_fichier' => 'Errour en tant que lou fichié s’escrieuguèsse sus lou disc',
	'erreur_format_fichier_image' => 'Lou fourmat de @nom@ noun counven a una image',
	'erreur_indiquez_un_fichier' => 'Endicas un fichié !',
	'erreur_insertion_document_base' => 'Empoussible de registrà lou doucumen @fichier@ en basa de dounada',
	'erreur_suppression_vignette' => 'Errour en tant que si suprimèsse la vigneta',
	'erreur_upload_type_interdit' => 'Lou telecargamen dei fichié de tìpou de @nom@ noun es autourisat',
	'erreur_upload_vignette' => 'Errour en tant que la vigneta @nom@ si cargue',
	'erreurs' => '@nb@ errour',
	'erreurs_voir' => 'Veire li @nb@ errour',

	// F
	'fichier_distant' => 'Fichié distant',
	'fichier_manquant' => 'Fichié mancant',
	'fichier_modifie' => 'Lou fichié es etat moudificat. Clicas soubre registrà.',
	'format_date_incorrect' => 'La data o l’oura es mau couret',

	// I
	'icone_creer_document' => 'Ajustà un doucumen',
	'id' => 'ID',
	'image_tourner_180' => 'Routacioun 180°',
	'image_tourner_droite' => 'Routacioun 90° a drecha',
	'image_tourner_gauche' => 'Routacioun 90° a seneca',
	'info_doc_max_poids' => 'Lu doucumen devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_document' => 'Doucumen',
	'info_document_indisponible' => 'Aquéu doucumen es pas dispounible',
	'info_documents' => 'Doucumen',
	'info_gauche_numero_document' => 'DOUCUMEN NUMERÒ',
	'info_hauteur' => 'Autessa',
	'info_heure' => 'Oura',
	'info_illustrations' => 'Ilustracioun',
	'info_image_max_poids' => 'Li image devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_image_max_taille' => 'Li image devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_inclusion_directe' => 'Enclusioun direta :',
	'info_inclusion_vignette' => 'Enclusioun de la vigneta :',
	'info_installer_tous_documents' => 'Instalà toui lu doucumen',
	'info_largeur' => 'Larguessa',
	'info_logo_max_taille' => 'Lu logou devon oubligatoriamen faire mens de @maxi@ (aqueu fichié fa @actuel@).',
	'info_mode' => 'Mòdou',
	'info_modifier_document' => 'Moudificà lou doucumen',
	'info_portfolio' => 'Pouòrtafoliò',
	'info_referencer_doc_distant' => 'Referençà un doucumen sus internet :',
	'info_sans_vignette' => 'Sensa vigneta',
	'info_statut_document' => 'Aquéu doucumen es :',
	'info_taille' => 'Pès',
	'info_telecharger' => 'Telecargà dau vouòstre ourdinatour :',
	'infos' => 'Infourmacioun tècniqui',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetre de moudificà la data de cada doucumen',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei doucumen es aquela dóu siéu ajountamen sus lou sit',

	// L
	'label_activer_document_objets' => 'Ativà lou televersamen ai contengut :',
	'label_apercu' => 'Aperçut',
	'label_caracteristiques' => 'Caraterìstica',
	'label_credits' => 'Crèdi',
	'label_fichier' => 'Fichié',
	'label_fichier_vignette' => 'Vigneta',
	'label_paginer_par' => 'Paginà per :',
	'label_parents' => 'Aqueu doucumen es estacat da',
	'label_refdoc_joindre' => 'Doucumen numerò',
	'lien_tout_enlever' => 'Levà tout', # MODIF
	'logo' => 'Logou',

	// M
	'media_audio' => 'Banda sounouri',
	'media_file' => 'Autre',
	'media_image' => 'Image',
	'media_video' => 'Sequènsa',
	'miniature_automatique_active' => 'SPIP genererà automaticamen una miniatura de l’image',

	// N
	'nb_documents_attache_succes' => '@nb@ doucumen soun ben estat ajustat',
	'nb_documents_installe_succes' => '@nb@ fichié cargat embé suchès',

	// O
	'objet_document' => 'Doucumen',
	'objet_documents' => 'Doucumen',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Autessa',
	'par_id' => 'ID',
	'par_largeur' => 'Larguessa',
	'par_taille' => 'Pès',
	'par_titre' => 'Titre',

	// T
	'texte_documents_joints' => 'Poudès ativà l’interfaça d’ajountamen de doucumen (fichié buròticou, image, multimedia, eca.) ai article, rùbrica e autre. Aquelu fichié pouòdon pi estre referençat en lou tèstou, o afichat separatamen.',
	'texte_documents_joints_2' => 'Aqueu reglage noun empedisse lou televersamen d’image en lu article ni l’ensercioun de doucumen diretamen en lu tèstou dei countengut.',
	'titre_documents_joints' => 'Doucumen jounch',
	'titre_page_documents_edit' => 'Moudificà lou doucumen : @titre@',
	'tous_les_medias' => 'Toui lu media',
	'tout_dossier_upload' => 'Tout lou doussié @upload@',
	'tout_voir' => 'Tout veire',

	// U
	'un_audio' => '1 banda sounoura',
	'un_document' => '1 doucumen',
	'un_file' => '1 doucumen',
	'un_image' => '1 image',
	'un_video' => '1 sequènsa',
	'une_utilisation' => '1 utilisacioun',
	'upload_fichier_zip' => 'Fichié ZIP',
	'upload_fichier_zip_texte' => 'Lou fichié que proupausas d’instalà es un fichié Zip.',
	'upload_fichier_zip_texte2' => 'Aquéu fichié pòu estre :',
	'upload_info_mode_document' => 'Depousà en lou pouòrtafoliò',
	'upload_info_mode_image' => 'Restirà dóu pouòrtafoliò',
	'upload_limit' => 'Aqueu fichié es tròu gros per lou servidou ; la talha massimala autourisada en <i>upload</i> es de @max@.',
	'upload_zip_conserver' => 'Counservà l’arquivi après estracioun',
	'upload_zip_decompacter' => 'descoumprimat e cada elemen que counten instalat sus lou sit. Lu fichié que seran pi instalat sus lou sit soun :',
	'upload_zip_mode_document' => 'Depousà touti li image en lou pouòrtafoliò',
	'upload_zip_telquel' => 'instalat tau quau, couma arquivi  coumprimat Zip ;',
	'upload_zip_titrer' => 'Titrà segoun lou noum dei fichié',

	// V
	'verifier_documents_brises' => 'Verificà lu fichié mancant',
	'verifier_documents_inutilises' => 'Verificà lu estac dei doucumen',
	'vignette_supprimee' => 'La vigneta es estada suprimada'
);
